@@ -11,9 +11,13 @@ select
     {#- Attributes #}
     products.product_id,
     products.valid_date_local,
-    products._fivetran_deleted
+    products._fivetran_deleted,
+    dispensaries.id
 from products
 inner join dispensaries
+    on
+        products.dispensary_id = dispensaries.dispensary_id
+        and products.valid_date_local = dispensaries.valid_date_local
 where not products._fivetran_deleted
 {% if is_incremental() -%}
     and products.valid_date_local >= (
