@@ -438,7 +438,7 @@ def test__templater_dbt_templating_absolute_path(
 
 
 @pytest.mark.parametrize(
-    "fname,exception_msg,exception_class",
+    ("fname", "exception_msg", "dbt_skip_compilation_error", "exception_class"),
     [
         (
             "compiler_error.sql",
@@ -446,6 +446,7 @@ def test__templater_dbt_templating_absolute_path(
             "(models/my_new_project/compiler_error.sql)\n  "
             "Unexpected end of template. Jinja was looking for the following tags: "
             "'endfor' or 'else'.",
+            True,
             SQLFluffUserError,
         ),
         (
@@ -454,6 +455,7 @@ def test__templater_dbt_templating_absolute_path(
             "Model 'model.my_new_project.unknown_ref' "
             "(models/my_new_project/unknown_ref.sql) depends on a node named "
             "'i_do_not_exist' which was not found",
+            True,
             SQLFluffUserError,
         ),
         (
@@ -462,6 +464,7 @@ def test__templater_dbt_templating_absolute_path(
             "Compilation Error in model unknown_macro "
             "(models/my_new_project/unknown_macro.sql)\n  'invalid_macro' is "
             "undefined. This can happen when calling a macro that does not exist.",
+            True,
             SQLTemplaterError,
         ),
         (
@@ -470,8 +473,16 @@ def test__templater_dbt_templating_absolute_path(
             # but in live testing, the inclusion of the triggering error sometimes
             # gives us something much more useful.
             "because dbt raised a fatal exception during compilation",
+            True,
             SQLFluffSkipFile,
         ),
+        pytest.param(
+            "compile_missing_table.sql",
+            "Runtime Error",
+            False,
+            SQLTemplaterError,
+            id="dbt_skip_compilation_error",
+        ),
     ],
 )
 def test__templater_dbt_handle_exceptions(
@@ -481,6 +492,7 @@ def test__templater_dbt_handle_exceptions(
     dbt_project_folder,
     fname,
     exception_msg,
+    dbt_skip_compilation_error,
     exception_class,
 ):
     """Test that exceptions during compilation are returned as violation."""
@@ -493,6 +505,9 @@ def test__templater_dbt_handle_exceptions(
     # We move the file that throws an error in and out of the project directory
     # as dbt throws an error if a node fails to parse while computing the DAG
     shutil.move(src_fpath, target_fpath)
+    dbt_fluff_config["templater"]["dbt"][
+        "dbt_skip_compilation_error"
+    ] = dbt_skip_compilation_error
     try:
         with pytest.raises(exception_class) as excinfo:
             dbt_templater.process(
@@ -592,6 +607,19 @@ def test__templater_dbt_handle_database_connection_failure(
     assert "dbt tried to connect to the database" in error_message
 
 
+def test__project_dir_from_env(dbt_templater, project_dir, monkeypatch):
+    """Test possibility to set project_dir from env variable."""
+    dbt_templater.sqlfluff_config = FluffConfig(
+        configs={
+            "core": {"dialect": "ansi"},
+            "templater": {"dbt": {"project_dir": None}},
+        }
+    )
+    assert dbt_templater._get_project_dir() == os.path.abspath(os.getcwd())
+    monkeypatch.setenv("DBT_PROJECT_DIR", project_dir)
+    assert dbt_templater._get_project_dir() == os.path.abspath(project_dir)
+
+
 def test__project_dir_does_not_exist_error(dbt_templater):
     """Test an error is logged if the given dbt project directory doesn't exist."""
     dbt_templater.sqlfluff_config = FluffConfig(
