@@ -1,6 +1,6 @@
 """The simple public API methods."""
 
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional
 
 from sqlfluff.core import (
     FluffConfig,
@@ -14,8 +14,8 @@ from sqlfluff.core.types import ConfigMappingType
 
 def get_simple_config(
     dialect: Optional[str] = None,
-    rules: Optional[List[str]] = None,
-    exclude_rules: Optional[List[str]] = None,
+    rules: Optional[list[str]] = None,
+    exclude_rules: Optional[list[str]] = None,
     config_path: Optional[str] = None,
 ) -> FluffConfig:
     """Get a config object from simple API arguments."""
@@ -38,11 +38,24 @@ def get_simple_config(
 
     # Instantiate a config object.
     try:
-        return FluffConfig.from_root(
+        config = FluffConfig.from_root(
             extra_config_path=config_path,
             ignore_local_config=True,
             overrides=overrides,
+            require_dialect=False,
         )
+
+        # If no dialect was specified, set it to ansi. This allows for the legacy
+        # behavior of the simple API to be maintained, where the dialect is not
+        # required to be specified, but defaults to ansi.
+        if not config.get("dialect"):
+            overrides["dialect"] = "ansi"
+            config = FluffConfig.from_root(
+                extra_config_path=config_path,
+                ignore_local_config=True,
+                overrides=overrides,
+            )
+        return config
     except SQLFluffUserError as err:  # pragma: no cover
         raise SQLFluffUserError(f"Error loading config: {str(err)}")
 
@@ -50,7 +63,7 @@ def get_simple_config(
 class APIParsingError(ValueError):
     """An exception which holds a set of violations."""
 
-    def __init__(self, violations: List[SQLBaseError], *args: Any):
+    def __init__(self, violations: list[SQLBaseError], *args: Any):
         self.violations = violations
         msg = f"Found {len(violations)} issues while parsing string."
         for viol in violations:
@@ -60,21 +73,21 @@ class APIParsingError(ValueError):
 
 def lint(
     sql: str,
-    dialect: str = "ansi",
-    rules: Optional[List[str]] = None,
-    exclude_rules: Optional[List[str]] = None,
+    dialect: Optional[str] = None,
+    rules: Optional[list[str]] = None,
+    exclude_rules: Optional[list[str]] = None,
     config: Optional[FluffConfig] = None,
     config_path: Optional[str] = None,
-) -> List[Dict[str, Any]]:
+) -> list[dict[str, Any]]:
     """Lint a SQL string.
 
     Args:
         sql (:obj:`str`): The SQL to be linted.
-        dialect (:obj:`str`, optional): A reference to the dialect of the SQL
+        dialect (:obj:`Optional[str]`, optional): A reference to the dialect of the SQL
             to be linted. Defaults to `ansi`.
-        rules (:obj:`Optional[List[str]`, optional): A list of rule
+        rules (:obj:`Optional[list[str]`, optional): A list of rule
             references to lint for. Defaults to None.
-        exclude_rules (:obj:`Optional[List[str]`, optional): A list of rule
+        exclude_rules (:obj:`Optional[list[str]`, optional): A list of rule
             references to avoid linting for. Defaults to None.
         config (:obj:`Optional[FluffConfig]`, optional): A configuration object
             to use for the operation. Defaults to None.
@@ -83,7 +96,7 @@ def lint(
             Defaults to None.
 
     Returns:
-        :obj:`List[Dict[str, Any]]` for each violation found.
+        :obj:`list[dict[str, Any]]` for each violation found.
     """
     cfg = config or get_simple_config(
         dialect=dialect,
@@ -101,9 +114,9 @@ def lint(
 
 def fix(
     sql: str,
-    dialect: str = "ansi",
-    rules: Optional[List[str]] = None,
-    exclude_rules: Optional[List[str]] = None,
+    dialect: Optional[str] = None,
+    rules: Optional[list[str]] = None,
+    exclude_rules: Optional[list[str]] = None,
     config: Optional[FluffConfig] = None,
     config_path: Optional[str] = None,
     fix_even_unparsable: Optional[bool] = None,
@@ -112,11 +125,11 @@ def fix(
 
     Args:
         sql (:obj:`str`): The SQL to be fixed.
-        dialect (:obj:`str`, optional): A reference to the dialect of the SQL
+        dialect (:obj:`Optional[str]`, optional): A reference to the dialect of the SQL
             to be fixed. Defaults to `ansi`.
-        rules (:obj:`Optional[List[str]`, optional): A subset of rule
+        rules (:obj:`Optional[list[str]`, optional): A subset of rule
             references to fix for. Defaults to None.
-        exclude_rules (:obj:`Optional[List[str]`, optional): A subset of rule
+        exclude_rules (:obj:`Optional[list[str]`, optional): A subset of rule
             references to avoid fixing for. Defaults to None.
         config (:obj:`Optional[FluffConfig]`, optional): A configuration object
             to use for the operation. Defaults to None.
@@ -154,15 +167,15 @@ def fix(
 
 def parse(
     sql: str,
-    dialect: str = "ansi",
+    dialect: Optional[str] = None,
     config: Optional[FluffConfig] = None,
     config_path: Optional[str] = None,
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """Parse a SQL string.
 
     Args:
         sql (:obj:`str`): The SQL to be parsed.
-        dialect (:obj:`str`, optional): A reference to the dialect of the SQL
+        dialect (:obj:`Optional[str]`, optional): A reference to the dialect of the SQL
             to be parsed. Defaults to `ansi`.
         config (:obj:`Optional[FluffConfig]`, optional): A configuration object
             to use for the operation. Defaults to None.
