@@ -8,7 +8,7 @@ from sqlfluff.core.parser.grammar.anyof import (
 )
 from sqlfluff.core.parser.grammar.base import Anything, Nothing, Ref
 from sqlfluff.core.parser.grammar.conditional import Conditional
-from sqlfluff.core.parser.grammar.delimited import Delimited
+from sqlfluff.core.parser.grammar.delimited import Delimited, OptionallyDelimited
 from sqlfluff.core.parser.grammar.sequence import Bracketed, Sequence
 
 __all__ = (
@@ -19,6 +19,7 @@ __all__ = (
     "AnySetOf",
     "OneOf",
     "OptionallyBracketed",
+    "OptionallyDelimited",
     "Delimited",
     "Sequence",
     "Bracketed",
