@@ -9,8 +9,9 @@ the context of each thread.
 
 import importlib.metadata
 import logging
+from collections.abc import Iterator
 from contextvars import ContextVar
-from typing import Iterator, Optional, Tuple
+from typing import Optional
 
 import pluggy
 
@@ -38,7 +39,7 @@ def _get_sqlfluff_version() -> str:
     return importlib.metadata.version("sqlfluff")
 
 
-def _discover_plugins() -> Iterator[Tuple[importlib.metadata.EntryPoint, str, str]]:
+def _discover_plugins() -> Iterator[tuple[importlib.metadata.EntryPoint, str, str]]:
     """Uses the same mechanism as pluggy to introspect available plugins.
 
     This method is then intended to allow loading of plugins individually,
