@@ -170,6 +170,7 @@ UNRESERVED_KEYWORDS = [
     "HIERARCHICAL",
     "HOUR",
     "ID",
+    "IDENTIFIED",
     "IF",
     "ILIKE",
     "IN",
@@ -219,6 +220,7 @@ UNRESERVED_KEYWORDS = [
     "OR",
     "OUTFILE",
     "OVERRIDE",
+    "PART",
     "PASTE",
     "POPULATE",
     "POSTGRESQL",
@@ -227,6 +229,7 @@ UNRESERVED_KEYWORDS = [
     "PROFILE",
     "PROJECTION",
     "QUARTER",
+    "QUERY",
     "QUOTA",
     "QUEUES",
     "RANGE",
