@@ -10,6 +10,7 @@ from sqlfluff.core.parser import (
     BinaryOperatorSegment,
     Bracketed,
     CodeSegment,
+    ComparisonOperatorSegment,
     Dedent,
     Delimited,
     IdentifierSegment,
@@ -62,6 +63,7 @@ duckdb_dialect.sets("unreserved_keywords").update(
     [
         "ANTI",
         "ASOF",
+        "GLOB",
         "MACRO",
         "MAP",
         "POSITIONAL",
@@ -73,6 +75,9 @@ duckdb_dialect.sets("unreserved_keywords").update(
 
 duckdb_dialect.add(
     LambdaArrowSegment=StringParser("->", SymbolSegment, type="lambda_arrow"),
+    OrIgnoreGrammar=Sequence("OR", "IGNORE"),
+    EqualsSegment_a=StringParser("==", ComparisonOperatorSegment),
+    UnpackingOperatorSegment=TypedParser("star", SymbolSegment, "unpacking_operator"),
 )
 
 duckdb_dialect.replace(
@@ -127,7 +132,9 @@ duckdb_dialect.replace(
         Ref("NamedArgumentSegment"),
         Ref("ExpressionSegment"),
     ),
-    ColumnsExpressionNameGrammar=Ref.keyword("COLUMNS"),
+    ColumnsExpressionNameGrammar=Sequence(
+        Ref("UnpackingOperatorSegment", optional=True), "COLUMNS"
+    ),
     # Uses grammar for LT06 support
     ColumnsExpressionGrammar=Sequence(
         Ref("ColumnsExpressionFunctionNameSegment"),
@@ -141,6 +148,17 @@ duckdb_dialect.replace(
         "single_quote", IdentifierSegment, type="quoted_identifier", casefold=str.lower
     ),
     ListComprehensionGrammar=Ref("ListComprehensionExpressionSegment"),
+    ComparisonOperatorGrammar=ansi_dialect.get_grammar(
+        "ComparisonOperatorGrammar"
+    ).copy(
+        insert=[
+            Ref("EqualsSegment_a"),
+            Ref("GlobOperatorSegment"),
+        ]
+    ),
+    LikeGrammar=postgres_dialect.get_grammar("LikeGrammar").copy(
+        insert=[Ref.keyword("GLOB")],
+    ),
 )
 
 duckdb_dialect.insert_lexer_matchers(
@@ -172,6 +190,7 @@ duckdb_dialect.patch_lexer_matchers(
                 "escape_replacements": [(r'""', '"')],
             },
         ),
+        RegexLexer("equals", r"==?", CodeSegment),
     ]
 )
 
@@ -227,6 +246,59 @@ class MapTypeSchemaSegment(BaseSegment):
     )
 
 
+class InsertStatementSegment(ansi.InsertStatementSegment):
+    """An `INSERT` Statement.
+
+    https://duckdb.org/docs/stable/sql/statements/insert.html
+    """
+
+    type = "insert_statement"
+    match_grammar: Matchable = Sequence(
+        "INSERT",
+        OneOf(Ref("OrReplaceGrammar"), Ref("OrIgnoreGrammar"), optional=True),
+        "INTO",
+        Ref("TableReferenceSegment"),
+        Ref("AsAliasExpressionSegment", optional=True),
+        OneOf(
+            Ref("BracketedColumnReferenceListGrammar"),
+            Sequence("BY", "POSITION"),
+            Sequence("BY", "NAME"),
+            optional=True,
+        ),
+        OneOf(
+            Sequence("DEFAULT", "VALUES"),
+            Ref("SelectStatementSegment"),
+            Sequence(
+                Ref("BracketedColumnReferenceListGrammar", optional=True),
+                OneOf(
+                    Ref("ValuesClauseSegment"),
+                    OptionallyBracketed(Ref("SelectStatementSegment")),
+                ),
+            ),
+        ),
+        Sequence(
+            "ON",
+            "CONFLICT",
+            Ref("ConflictTargetSegment", optional=True),
+            Ref("ConflictActionSegment"),
+            optional=True,
+        ),
+        Sequence(
+            "RETURNING",
+            OneOf(
+                Ref("StarSegment"),
+                Delimited(
+                    Sequence(
+                        Ref("ExpressionSegment"),
+                        Ref("AsAliasExpressionSegment", optional=True),
+                    ),
+                ),
+            ),
+            optional=True,
+        ),
+    )
+
+
 class ColumnConstraintSegment(ansi.ColumnConstraintSegment):
     """A column option; each CREATE TABLE column can have 0 or more.
 
@@ -352,6 +424,45 @@ class WildcardReplaceExpressionSegment(BaseSegment):
     )
 
 
+class WildcardRenameExpressionSegment(BaseSegment):
+    """A `RENAME` clause within a wildcard expression."""
+
+    type = "wildcard_rename"
+    match_grammar = Sequence(
+        "RENAME",
+        OneOf(
+            Bracketed(
+                Delimited(
+                    Sequence(
+                        Ref("BaseExpressionElementGrammar"),
+                        Ref("AliasExpressionSegment", optional=True),
+                    ),
+                )
+            ),
+            Sequence(
+                Ref("BaseExpressionElementGrammar"),
+                Ref("AliasExpressionSegment", optional=True),
+            ),
+        ),
+    )
+
+
+class WildcardPatternMatchingSegment(BaseSegment):
+    """A pattern matching operator clause within a wildcard expression."""
+
+    type = "wildcard_pattern_matching"
+    match_grammar = OneOf(
+        Ref("LikeExpressionGrammar"),
+        Sequence(
+            OneOf(
+                Ref("LikeOperatorSegment"),
+                Ref("GlobOperatorSegment"),
+            ),
+            Ref("QuotedLiteralSegment"),
+        ),
+    )
+
+
 class WildcardExpressionSegment(ansi.WildcardExpressionSegment):
     """An extension of the star expression for DuckDB."""
 
@@ -360,7 +471,14 @@ class WildcardExpressionSegment(ansi.WildcardExpressionSegment):
         Ref("WildcardIdentifierSegment"),
         # Optional EXCLUDE or REPLACE clause
         Ref("WildcardExcludeExpressionSegment", optional=True),
-        Ref("WildcardReplaceExpressionSegment", optional=True),
+        OneOf(
+            Sequence(
+                Ref("WildcardReplaceExpressionSegment", optional=True),
+                Ref("WildcardRenameExpressionSegment", optional=True),
+            ),
+            Ref("WildcardPatternMatchingSegment"),
+            optional=True,
+        ),
     )
 
 
@@ -395,8 +513,8 @@ class ColumnsExpressionFunctionContentsSegment(
         Bracketed(
             OneOf(
                 Ref("WildcardExpressionSegment"),
-                Ref("QuotedLiteralSegment"),
                 Ref("LambdaExpressionSegment"),
+                Ref("BaseExpressionElementGrammar"),
             ),
         ),
     )
@@ -449,6 +567,16 @@ class SelectStatementSegment(ansi.SelectStatementSegment):
     match_grammar = ansi.SelectStatementSegment.match_grammar.copy(
         insert=[Ref("QualifyClauseSegment", optional=True)],
         before=Ref("OrderByClauseSegment", optional=True),
+        replace_terminators=True,
+        terminators=[
+            Ref("SetOperatorSegment"),
+            Ref("WithNoSchemaBindingClauseSegment"),
+            Ref("WithDataClauseSegment"),
+            Sequence("ON", "CONFLICT"),
+            "RETURNING",
+            Ref("WithCheckOptionSegment"),
+            Ref("MetaCommandQueryBufferSegment"),
+        ],
     )
 
 
@@ -484,6 +612,8 @@ class UnorderedSelectStatementSegment(ansi.UnorderedSelectStatementSegment):
             Ref("SetOperatorSegment"),
             Ref("OrderByClauseSegment"),
             Ref("LimitClauseSegment"),
+            Sequence("ON", "CONFLICT"),
+            "RETURNING",
         ],
     )
 
