@@ -185,6 +185,7 @@ ANYELEMENT
 APPLY
 APPROXIMATE
 ARE
+ARN
 ARRAY_AGG
 ARRAY_MAX_CARDINALITY
 ASENSITIVE
@@ -198,6 +199,8 @@ ATOMIC
 ATTACH
 ATTRIBUTE
 ATTRIBUTES
+AUTHENTICATION
+AUTHENTICATION_ARN
 AUTO
 AUTO_INCREMENT
 AVG
@@ -254,6 +257,7 @@ CHARACTER_SET_NAME
 CHARACTER_SET_SCHEMA
 CHAR_LENGTH
 CHECKPOINT
+CI
 CLASS
 CLASSIFIER
 CLASS_ORIGIN
@@ -286,6 +290,7 @@ CONFIGURATION
 CONFLICT
 CONNECT
 CONNECTION
+CONNECTION_LIMIT
 CONNECTION_NAME
 CONSTRAINTS
 CONSTRAINT_CATALOG
@@ -311,6 +316,7 @@ COVAR_SAMP
 CREATEDB
 CREATEUSER
 CREATEROLE
+CS
 CSV
 CUBE
 CUME_DIST
@@ -327,6 +333,7 @@ CURSOR_NAME
 CYCLE
 DATA
 DATABASE
+DATA_CATALOG_SCHEMA
 DATALINK
 DATASHARE
 DATASHARES
@@ -337,6 +344,7 @@ DATETIME_INTERVAL_PRECISION
 DAY
 DAYOFYEAR
 DB
+DBUSER
 DEALLOCATE
 DEC
 DECFLOAT
@@ -383,6 +391,7 @@ DOCUMENT
 DOMAIN
 DOUBLE
 DROP
+DUPLICATES
 DYNAMIC
 DYNAMIC_FUNCTION
 DYNAMIC_FUNCTION_CODE
@@ -474,11 +483,13 @@ HASH
 HEADER
 HEX
 HIERARCHY
+HISTORY_MODE
 HIVE
 HLLSKETCH
 HOLD
 HOUR
 HYPERPARAMETERS
+IAM
 IAM_ROLE
 ID
 IF
@@ -533,6 +544,7 @@ JSON_TABLE
 JSON_TABLE_PRIMITIVE
 JSON_VALUE
 K
+KAFKA
 KEEP
 KEY
 KEYS
@@ -621,6 +633,8 @@ MONITOR
 MONTH
 MORE
 MOVE
+MSK
+MTLS
 MULTICLASS_CLASSIFICATION
 MULTISET
 MYSQL
@@ -653,6 +667,7 @@ NOLOGIN
 NOREPLICATION
 NOSUPERUSER
 NONE
+NONATOMIC
 NOORDER
 NORMALIZE
 OUTPUTFORMAT
@@ -760,6 +775,7 @@ PUBLICATION
 PLPYTHONU
 QUALIFY
 QUARTER
+QUERY_ALL_STATES
 QUOTA
 QUOTE
 QUOTES
@@ -781,6 +797,7 @@ REFCURSOR
 REFERENCE_USAGE
 REFERENCING
 REFRESH
+REFRESH_INTERVAL
 REGION
 REGR_AVGX
 REGR_AVGY
@@ -1020,6 +1037,7 @@ USER_DEFINED_TYPE_CATALOG
 USER_DEFINED_TYPE_CODE
 USER_DEFINED_TYPE_NAME
 USER_DEFINED_TYPE_SCHEMA
+USER_LIMIT
 UTF16
 UTF16BE
 UTF16LE
