@@ -1,6 +1,6 @@
 """Implementation of Rule CV05."""
 
-from typing import List, Optional, Union
+from typing import Optional, Union
 
 from sqlfluff.core.parser import KeywordSegment, WhitespaceSegment
 from sqlfluff.core.rules import BaseRule, LintResult, RuleContext
@@ -8,7 +8,7 @@ from sqlfluff.core.rules.crawlers import SegmentSeekerCrawler
 from sqlfluff.utils.functional import Segments, sp
 from sqlfluff.utils.reflow import ReflowSequence
 
-CorrectionListType = List[Union[WhitespaceSegment, KeywordSegment]]
+CorrectionListType = list[Union[WhitespaceSegment, KeywordSegment]]
 
 
 class Rule_CV05(BaseRule):
@@ -76,8 +76,26 @@ class Rule_CV05(BaseRule):
         if context.segment.raw not in ("=", "!=", "<>"):
             return None
 
-        # We only care if it's followed by a NULL literal.
+        # Check if this is a T-SQL variable assignment in a SELECT statement
+        # In T-SQL, @Variable = NULL is an assignment, not a comparison
         siblings = Segments(*context.parent_stack[-1].segments)
+        before_op_list = siblings.select(stop_seg=context.segment)
+        prev_code = before_op_list.last(sp.is_code())
+
+        # If the previous code is a parameter (T-SQL variable starting with @)
+        # and we're in a select_clause_element, this is likely a variable assignment
+        prev_code_seg = prev_code.get() if prev_code else None
+        if (
+            prev_code_seg
+            and prev_code_seg.is_type("parameter")
+            and prev_code_seg.raw.startswith("@")
+            and any(
+                seg.is_type("select_clause_element") for seg in context.parent_stack
+            )
+        ):
+            return None
+
+        # We only care if it's followed by a NULL literal.
         after_op_list = siblings.select(start_seg=context.segment)
         next_code = after_op_list.first(sp.is_code())
 
