@@ -1,6 +1,6 @@
 """Implementation of Rule LT01."""
 
-from typing import List, Optional
+from typing import Optional
 
 from sqlfluff.core.rules import BaseRule, LintResult, RuleContext
 from sqlfluff.core.rules.crawlers import RootOnlyCrawler
@@ -65,7 +65,7 @@ class Rule_LT01(BaseRule):
     crawl_behaviour = RootOnlyCrawler()
     is_fix_compatible = True
 
-    def _eval(self, context: RuleContext) -> Optional[List[LintResult]]:
+    def _eval(self, context: RuleContext) -> Optional[list[LintResult]]:
         """Unnecessary whitespace."""
         sequence = ReflowSequence.from_root(context.segment, config=context.config)
         return sequence.respace().get_results()
