@@ -1,19 +1,22 @@
 """Surrogate class for working with RawFileSlice collections."""
+
 from typing import Callable, Optional
 
 from sqlfluff.core.templaters.base import RawFileSlice, TemplatedFile
 
 
-class RawFileSlices(tuple):
+class RawFileSlices(tuple[RawFileSlice, ...]):
     """Encapsulates a sequence of one or more RawFileSlice.
 
     The slices may or may not be contiguous in a file.
     Provides useful operations on a sequence of slices to simplify rule creation.
     """
 
-    def __new__(cls, *raw_slices, templated_file=None):
+    def __new__(
+        cls, *raw_slices: RawFileSlice, templated_file: Optional[TemplatedFile] = None
+    ) -> "RawFileSlices":
         """Override new operator."""
-        return super(RawFileSlices, cls).__new__(cls, raw_slices)
+        return super().__new__(cls, raw_slices)
 
     def __init__(self, *_: RawFileSlice, templated_file: TemplatedFile):
         self.templated_file = templated_file
