@@ -1,8 +1,9 @@
 """Dataclasses for reflow work."""
 
 import logging
+from collections.abc import Iterator, Sequence
 from itertools import chain
-from typing import Iterator, List, Literal, Optional, Sequence, Tuple, Type, cast
+from typing import Literal, Optional, cast
 
 from sqlfluff.core.config import FluffConfig
 from sqlfluff.core.parser import BaseSegment, RawSegment
@@ -65,7 +66,7 @@ class ReflowSequence:
         root_segment: BaseSegment,
         reflow_config: ReflowConfig,
         depth_map: DepthMap,
-        lint_results: Optional[List[LintResult]] = None,
+        lint_results: Optional[list[LintResult]] = None,
     ):
         # First validate integrity
         self._validate_reflow_sequence(elements)
@@ -81,9 +82,9 @@ class ReflowSequence:
         # Rather than saving *fixes* directly, we package them into
         # LintResult objects to make it a little easier to expose them
         # in the CLI.
-        self.lint_results: List[LintResult] = lint_results or []
+        self.lint_results: list[LintResult] = lint_results or []
 
-    def get_fixes(self) -> List[LintFix]:
+    def get_fixes(self) -> list[LintFix]:
         """Get the current fix buffer.
 
         We're hydrating them here directly from the LintResult
@@ -93,7 +94,7 @@ class ReflowSequence:
         """
         return fixes_from_results(self.lint_results)
 
-    def get_results(self) -> List[LintResult]:
+    def get_results(self) -> list[LintResult]:
         """Return the current result buffer."""
         return self.lint_results
 
@@ -136,7 +137,7 @@ class ReflowSequence:
         which simplifies iteration here.
         """
         elem_buff: ReflowSequenceType = []
-        seg_buff: List[RawSegment] = []
+        seg_buff: list[RawSegment] = []
         for seg in segments:
             # NOTE: end_of_file is block-like rather than point-like.
             # This is to facilitate better evaluation of the ends of files.
@@ -172,7 +173,7 @@ class ReflowSequence:
 
     @classmethod
     def from_raw_segments(
-        cls: Type["ReflowSequence"],
+        cls: type["ReflowSequence"],
         segments: Sequence[RawSegment],
         root_segment: BaseSegment,
         config: FluffConfig,
@@ -206,7 +207,7 @@ class ReflowSequence:
 
     @classmethod
     def from_root(
-        cls: Type["ReflowSequence"], root_segment: BaseSegment, config: FluffConfig
+        cls: type["ReflowSequence"], root_segment: BaseSegment, config: FluffConfig
     ) -> "ReflowSequence":
         """Generate a sequence from a root segment.
 
@@ -226,7 +227,7 @@ class ReflowSequence:
 
     @classmethod
     def from_around_target(
-        cls: Type["ReflowSequence"],
+        cls: type["ReflowSequence"],
         target_segment: BaseSegment,
         root_segment: BaseSegment,
         config: FluffConfig,
@@ -289,19 +290,31 @@ class ReflowSequence:
         )
         return cls.from_raw_segments(segments, root_segment, config=config)
 
-    def _find_element_idx_with(self, target: RawSegment) -> int:
+    def _find_element_idx_with(self, target: RawSegment) -> int:  # pragma: no cover
+        """Helper method to find an element within a segment.
+
+        Note:
+            This method is currently excluded from test coverage because it is not
+            actively used by any rule. It was previously utilized by rule AL01,
+            but that rule now uses an alternative implementation. The method is
+            retained for potential future reuse or reference.
+        """
         for idx, elem in enumerate(self.elements):
             if target in elem.segments:
                 return idx
-        raise ValueError(  # pragma: no cover
-            f"Target [{target}] not found in ReflowSequence."
-        )
+        raise ValueError(f"Target [{target}] not found in ReflowSequence.")
 
-    def without(self, target: RawSegment) -> "ReflowSequence":
+    def without(self, target: RawSegment) -> "ReflowSequence":  # pragma: no cover
         """Returns a new :obj:`ReflowSequence` without the specified segment.
 
         This generates appropriate deletion :obj:`LintFix` objects
         to direct the linter to remove those elements.
+
+        Note:
+            This method is currently excluded from test coverage because it is not
+            actively used by any rule. It was previously utilized by rule AL01,
+            but that rule now uses an alternative implementation. The method is
+            retained for potential future reuse or reference.
         """
         removal_idx = self._find_element_idx_with(target)
         if removal_idx == 0 or removal_idx == len(self.elements) - 1:
@@ -329,12 +342,18 @@ class ReflowSequence:
 
     def insert(
         self, insertion: RawSegment, target: RawSegment, pos: str = "before"
-    ) -> "ReflowSequence":
+    ) -> "ReflowSequence":  # pragma: no cover
         """Returns a new :obj:`ReflowSequence` with the new element inserted.
 
         Insertion is always relative to an existing element. Either before
         or after it as specified by `pos`. This generates appropriate creation
         :obj:`LintFix` objects to direct the linter to insert those elements.
+
+        Note:
+            This method is currently excluded from test coverage because it is not
+            actively used by any rule. It was previously utilized by rule AL01,
+            but that rule now uses an alternative implementation. The method is
+            retained for potential future reuse or reference.
         """
         assert pos in ("before", "after")
         target_idx = self._find_element_idx_with(target)
@@ -447,7 +466,7 @@ class ReflowSequence:
 
     def _iter_points_with_constraints(
         self,
-    ) -> Iterator[Tuple[ReflowPoint, Optional[ReflowBlock], Optional[ReflowBlock]]]:
+    ) -> Iterator[tuple[ReflowPoint, Optional[ReflowBlock], Optional[ReflowBlock]]]:
         for idx, elem in enumerate(self.elements):
             # Only evaluate points.
             if isinstance(elem, ReflowPoint):
@@ -609,8 +628,7 @@ class ReflowSequence:
         """
         if self.lint_results:
             raise NotImplementedError(  # pragma: no cover
-                "break_long_lines cannot currently handle pre-existing "
-                "embodied fixes."
+                "break_long_lines cannot currently handle pre-existing embodied fixes."
             )
 
         single_indent = construct_single_indent(
