@@ -39,7 +39,7 @@ from sqlfluff.utils.testing.cli import invoke_assert_code
 if sys.version_info >= (3, 11):
     import tomllib
 else:  # pragma: no cover
-    import toml as tomllib
+    import tomli as tomllib
 
 
 re_ansi_escape = re.compile(r"\x1b[^m]*m")
@@ -307,6 +307,13 @@ stdin_cli_input = (
             "Parsing errors found and dialect is set to 'ansi'.",
             "",
         ),
+        (
+            lint,
+            "test/fixtures/cli/stdin_filename/ignored.sql",
+            0,
+            "re-run with `--disregard-sqlfluffignores`",
+            "",
+        ),
         (
             cli_format,
             "test/fixtures/cli/stdin_filename/stdin_filename.sql",
@@ -328,6 +335,13 @@ stdin_cli_input = (
             "",
             "[1 templating/parsing errors found]",
         ),
+        (
+            cli_format,
+            "test/fixtures/cli/stdin_filename/ignored.sql",
+            0,
+            stdin_cli_input,
+            "re-run with `--disregard-sqlfluffignores`",
+        ),
         (
             fix,
             "test/fixtures/cli/stdin_filename/stdin_filename.sql",
@@ -349,6 +363,13 @@ stdin_cli_input = (
             "",
             "Unfixable violations detected.",
         ),
+        (
+            fix,
+            "test/fixtures/cli/stdin_filename/ignored.sql",
+            0,
+            stdin_cli_input,
+            "re-run with `--disregard-sqlfluffignores`",
+        ),
     ],
 )
 def test__cli__command_stdin_filename_config(
