@@ -1,4 +1,5 @@
 """The Test file for CLI Formatters."""
+
 import pathlib
 import re
 import textwrap
@@ -9,12 +10,12 @@ from sqlfluff.cli.commands import fix
 from sqlfluff.cli.formatters import OutputStreamFormatter
 from sqlfluff.cli.outputstream import FileOutput
 from sqlfluff.core import FluffConfig
-from sqlfluff.core.enums import Color
 from sqlfluff.core.errors import SQLLintError
 from sqlfluff.core.parser import RawSegment
 from sqlfluff.core.parser.markers import PositionMarker
 from sqlfluff.core.rules import RuleGhost
 from sqlfluff.core.templaters.base import TemplatedFile
+from sqlfluff.core.types import Color
 
 
 def escape_ansi(line):
@@ -90,7 +91,7 @@ def test__cli__helpers__cli_table(tmpdir):
                 "rule VARCHAR(30)"
                 ");"
             ),
-            ["--force", "--dialect", "postgres", "--disable_progress_bar", "--nocolor"],
+            ["--force", "--dialect", "postgres", "--disable-progress-bar", "--nocolor"],
             (
                 "CREATE TABLE IF NOT EXISTS vuln.software_name_dictionary("
                 "id SERIAL PRIMARY KEY"
