@@ -1,4 +1,5 @@
 """Tests for the standard set of rules."""
+
 import logging
 
 import pytest
@@ -228,10 +229,26 @@ def test__rules__result_unparsable():
     assert res.tree.raw == raw_sql
 
 
-def test__rules__runaway_fail_catch():
+@pytest.mark.parametrize(
+    "sql_query, check_tuples",
+    [
+        (
+            "SELECT * FROM foo",
+            # Even though there's a runaway fix, we should still
+            # find each issue once and not duplicates of them.
+            [
+                ("T001", 1, 7),
+                ("T001", 1, 9),
+                ("T001", 1, 14),
+            ],
+        ),
+        # If the errors are disabled, they shouldn't come through.
+        ("-- noqa: disable=all\nSELECT * FROM foo", []),
+    ],
+)
+def test__rules__runaway_fail_catch(sql_query, check_tuples):
     """Test that we catch runaway rules."""
     runaway_limit = 5
-    my_query = "SELECT * FROM foo"
     # Set up the config to only use the rule we are testing.
     cfg = FluffConfig(
         overrides={"rules": "T001", "runaway_limit": runaway_limit, "dialect": "ansi"}
@@ -240,9 +257,11 @@ def test__rules__runaway_fail_catch():
     linter = Linter(config=cfg, user_rules=[Rule_T001])
     # In theory this step should result in an infinite
     # loop, but the loop limit should catch it.
-    linted = linter.lint_string(my_query, fix=True)
+    result = linter.lint_string(sql_query, fix=True)
     # When the linter hits the runaway limit, it returns the original SQL tree.
-    assert linted.tree.raw == my_query
+    assert result.tree.raw == sql_query
+    # Check the issues found.
+    assert result.check_tuples() == check_tuples
 
 
 def test_rules_cannot_be_instantiated_without_declared_configs():
@@ -251,11 +270,11 @@ def test_rules_cannot_be_instantiated_without_declared_configs():
     class Rule_NewRule_ZZ99(BaseRule):
         """Testing Rule."""
 
-        config_keywords = ["tab_space_size"]
+        config_keywords = ["case_sensitive"]
 
-    new_rule = Rule_NewRule_ZZ99(code="L000", description="", tab_space_size=6)
-    assert new_rule.tab_space_size == 6
-    # Error is thrown since "tab_space_size" is defined in class,
+    new_rule = Rule_NewRule_ZZ99(code="L000", description="", case_sensitive=False)
+    assert new_rule.case_sensitive is False
+    # Error is thrown since "case_sensitive" is defined in class,
     # but not upon instantiation
     with pytest.raises(ValueError):
         new_rule = Rule_NewRule_ZZ99(code="L000", description="")
