@@ -220,13 +220,12 @@ def test__dialect__ansi_parse_indented_joins(sql_string, indented_joins, meta_lo
         )
     )
     parsed = lnt.parse_string(sql_string)
+    tree = parsed.tree
     # Check that there's nothing unparsable
-    assert "unparsable" not in parsed.tree.type_set()
+    assert "unparsable" not in tree.type_set()
     # Check all the segments that *should* be metas, ARE.
     # NOTE: This includes the end of file marker.
     res_meta_locs = tuple(
-        idx
-        for idx, raw_seg in enumerate(parsed.tree.get_raw_segments())
-        if raw_seg.is_meta
+        idx for idx, raw_seg in enumerate(tree.get_raw_segments()) if raw_seg.is_meta
     )
     assert res_meta_locs == meta_loc
