@@ -8,4 +8,5 @@ SELECT COL2 FROM TABLE2
 
 -- COMMAND ----------
 
-SELECT COL3 FROM TABLE3
+SELECT COL3 FROM TABLE3;
+SELECT COL4 FROM TABLE4;
