@@ -1,4 +1,4 @@
--- BASIC CREATE VIEW 
+-- BASIC CREATE VIEW
 CREATE VIEW NEW_VIEW AS (select PERSON_ID from PERSONS p);
 
 -- CREATE OR REPLACE
@@ -25,3 +25,9 @@ CREATE EDITIONABLE EDITIONING VIEW NEW_VIEW AS (select PERSON_ID from PERSONS p)
 
 -- CREATE OR REPLACE VIEW WITH EDITIONING
 CREATE OR REPLACE EDITIONING VIEW NEW_VIEW AS (select PERSON_ID from PERSONS p);
+
+-- CREATE MATERIALIZED VIEW
+CREATE MATERIALIZED VIEW NEW_VIEW AS( select PERSON_ID from PERSONS p);
+
+-- CREATE OR REPLACE MATERIALIZED VIEW
+CREATE OR REPLACE MATERIALIZED VIEW NEW_VIEW AS( select PERSON_ID from PERSONS p);
