@@ -22,3 +22,5 @@ GRANT CONNECT, CREATE, TEMP, TEMPORARY ON DATABASE my_db TO xyz;
 GRANT CONNECT, CREATE, TEMP, TEMPORARY ON DATABASE my_db TO my_user, my_other_user WITH GRANT OPTION;
 GRANT SELECT ON abc TO xyz, mno;
 GRANT EXECUTE ON ALL ROUTINES IN SCHEMA my_schema TO my_user, my_other_user;
+GRANT EXECUTE ON FUNCTION test(a IN TEXT, b OUT TEXT, INOUT c TEXT, VARIADIC d TEXT) TO my_user;
+GRANT EXECUTE ON FUNCTION test(a TEXT, b my_table.my_column%type) TO my_user;
