@@ -34,6 +34,9 @@ alter warehouse set warehouse_size=medium;
 alter warehouse LOAD_WH set WAREHOUSE_TYPE = STANDARD;
 alter warehouse LOAD_WH set WAREHOUSE_TYPE = 'SNOWPARK-OPTIMIZED';
 
+alter warehouse LOAD_WH set RESOURCE_CONSTRAINT = 'MEMORY_64X';
+alter warehouse LOAD_WH set RESOURCE_CONSTRAINT = MEMORY_1X;
+
 ALTER WAREHOUSE IDENTIFIER($var_wh) SET WAREHOUSE_TYPE = STANDARD;
 
 ALTER WAREHOUSE CI_TRANSFORMING
