@@ -112,3 +112,7 @@ CREATE OR ALTER TASK mytask
     LOG_LEVEL = TRACE
 AS
     CALL SCH.MY_SPROC();
+
+CREATE TASK mytask
+AS
+    ALTER DYNAMIC TABLE foo REFRESH;
