@@ -118,3 +118,7 @@ DESC PROCEDURE area_of_circle(FLOAT);
 DESCRIBE EXTERNAL VOLUME my_volume;
 
 DESC PASSWORD POLICY password_policy_prod_1;
+
+DESCRIBE CORTEX SEARCH SERVICE mysvc;
+
+DESC CORTEX SEARCH SERVICE mysvc;
