@@ -111,3 +111,7 @@ DROP WAREHOUSE IF EXISTS MY_WAREHOUSE;
 DROP EXTERNAL VOLUME my_volume;
 
 DROP EXTERNAL VOLUME IF EXISTS foo;
+
+DROP CORTEX SEARCH SERVICE mysvc;
+
+DROP CORTEX SEARCH SERVICE IF EXISTS mysvc;
