@@ -14,5 +14,13 @@ ADD JAR "ivy://group:module:version?transitive=true";
 
 ADD JAR "ivy://group:module:version?exclude=group:module&transitive=true";
 
--- NB: Non-quoted paths are not supported in SQLFluff currently
---ADD JAR /tmp/test.jar;
+ADD JAR ivy://group:module:version?exclude=group:module&transitive=true;
+
+ADD JAR /path/to/some.jar;
+
+ADD JAR path/to/some.jar;
+
+ADD JAR ivy://path/to/some.jar;
+
+-- NB: Non-quoted paths do not currently support whitespaces
+-- e.g. /path to/some.jar
