@@ -12,3 +12,8 @@ CREATE TABLE users (
 CREATE TABLE users (
     user_id INTEGER PRIMARY KEY DESC AUTOINCREMENT
 );
+
+CREATE TABLE example (
+    id INTEGER PRIMARY KEY,
+    description CHARACTER VARYING(32) NOT NULL
+);
