@@ -85,3 +85,35 @@ CREATE VOLATILE TABLE f AS (SELECT 'A' AS B) WITH NO DATA AND NO STATS;
 CREATE VOLATILE TABLE g AS (SELECT 'A' AS B) WITH NO DATA AND STATISTICS;
 
 CREATE VOLATILE TABLE h AS (SELECT 'A' AS B) WITH NO DATA AND NO STATISTICS ON COMMIT PRESERVE ROWS;
+
+-- Testing of the set tables with options
+CREATE SET TABLE TABLE_2, FALLBACK ,
+    NO BEFORE JOURNAL,
+    NO AFTER JOURNAL,
+    CHECKSUM = DEFAULT,
+    DEFAULT MERGEBLOCKRATIO,
+    MAP = TD_MAP1 (
+    CHAR_FIELD CHAR(19) CHARACTER
+    SET
+    LATIN NOT CASESPECIFIC NOT NULL,
+    DATE_FIELD DATE FORMAT 'YYYY-MM-DD' NOT NULL,
+    BYTE_FIELD BYTEINT COMPRESS 0,
+    DECIMAL_FIELD DECIMAL(15, 2) COMPRESS (
+        50.00,
+        45.50,
+        40.00,
+        30.00,
+        27.80,
+        27.05,
+        20.00,
+        17.87,
+        17.56,
+        17.41,
+        17.26,
+        17.11,
+        16.96,
+        16.82,
+        16.68
+    ),
+    TIMESTAMP_FIELD TIMESTAMP(6) NOT NULL
+) PRIMARY INDEX (CHAR_FIELD, DATE_FIELD, BYTE_FIELD);
